@@ -193,7 +193,7 @@ release_tile (GeglBufferIterator *iter,
   if (sub->current_tile_mode == GeglIteratorTileMode_DirectTile)
     {
       if (sub->access_mode & GEGL_ACCESS_WRITE)
-        gegl_tile_unlock (sub->current_tile);
+        gegl_tile_unlock_no_void (sub->current_tile);
       gegl_tile_unref (sub->current_tile);
 
       sub->current_tile = NULL;
@@ -545,10 +545,26 @@ _gegl_buffer_iterator_stop (GeglBufferIterator *iter)
           if (sub->linear_tile)
             {
               if (sub->access_mode & GEGL_ACCESS_WRITE)
-                gegl_tile_unlock (sub->linear_tile);
+                gegl_tile_unlock_no_void (sub->linear_tile);
               gegl_tile_unref (sub->linear_tile);
             }
 
+          if (sub->level == 0                      &&
+              sub->access_mode & GEGL_ACCESS_WRITE &&
+              ! (sub->access_mode & GEGL_ITERATOR_INCOMPATIBLE))
+            {
+              GeglRectangle damage_rect;
+
+              damage_rect.x      = sub->full_rect.x + sub->buffer->shift_x;
+              damage_rect.y      = sub->full_rect.y + sub->buffer->shift_y;
+              damage_rect.width  = sub->full_rect.width;
+              damage_rect.height = sub->full_rect.height;
+
+              gegl_tile_handler_damage_rect (
+                GEGL_TILE_HANDLER (sub->buffer->tile_storage),
+                &damage_rect);
+            }
+
           gegl_buffer_unlock (sub->buffer);
 
           if ((sub->access_mode & GEGL_ACCESS_WRITE) &&
