@@ -53,13 +53,6 @@ struct _GeglBuffer
                                             should track any modifications to the
                                             extent rectangle */
 
-
-  GeglSampler      *sampler; /* cached sampler for speeding up random
-                                access interpolated fetches from the
-                                buffer */
-  GeglSamplerType   sampler_type;
-  const Babl       *sampler_format; /* the format of the cached sampler */
-
   GeglTileStorage  *tile_storage;
 
   gint              tile_width;
