@@ -358,18 +358,12 @@ void
 _gegl_buffer_drop_hot_tile (GeglBuffer *buffer)
 {
   GeglTileStorage *storage = buffer->tile_storage;
+  GeglTile        *tile;
 
-  if (gegl_config_threads()>1)
-    g_rec_mutex_lock (&storage->mutex);
+  tile = gegl_tile_storage_steal_hot_tile (storage);
 
-  if (storage->hot_tile)
-    {
-      gegl_tile_unref (storage->hot_tile);
-      storage->hot_tile = NULL;
-    }
-
-  if (gegl_config_threads()>1)
-    g_rec_mutex_unlock (&storage->mutex);
+  if (tile)
+    gegl_tile_unref (tile);
 }
 
 static void
@@ -378,8 +372,6 @@ gegl_buffer_dispose (GObject *object)
   GeglBuffer  *buffer  = GEGL_BUFFER (object);
   GeglTileHandler *handler = GEGL_TILE_HANDLER (object);
 
-  gegl_buffer_sample_cleanup (buffer);
-
   if (gegl_cl_is_accelerated ())
     gegl_buffer_cl_cache_invalidate (GEGL_BUFFER (object), NULL);
 
