@@ -116,9 +116,7 @@ gegl_tile_handler_cache_init (GeglTileHandlerCache *cache)
   g_queue_init (&cache->queue);
   gegl_tile_cache_init ();
 
-  g_mutex_lock (&mutex);
-  g_queue_push_tail_link (&cache_queue, &cache->link);
-  g_mutex_unlock (&mutex);
+  gegl_tile_handler_cache_connect (cache);
 }
 
 static void
@@ -128,21 +126,10 @@ drop_hot_tile (GeglTile *tile)
 
   if (storage)
     {
-#if 0 /* the storage's mutex should already be locked at this point */
-      if (gegl_config_threads()>1)
-        g_rec_mutex_lock (&storage->mutex);
-#endif
+      tile = gegl_tile_storage_try_steal_hot_tile (storage, tile);
 
-      if (storage->hot_tile == tile)
-        {
-          gegl_tile_unref (storage->hot_tile);
-          storage->hot_tile = NULL;
-        }
-
-#if 0
-      if (gegl_config_threads()>1)
-        g_rec_mutex_unlock (&storage->mutex);
-#endif
+      if (tile)
+        gegl_tile_unref (tile);
     }
 }
 
@@ -184,9 +171,7 @@ gegl_tile_handler_cache_dispose (GObject *object)
 {
   GeglTileHandlerCache *cache = GEGL_TILE_HANDLER_CACHE (object);
 
-  g_mutex_lock (&mutex);
-  g_queue_unlink (&cache_queue, &cache->link);
-  g_mutex_unlock (&mutex);
+  gegl_tile_handler_cache_disconnect (cache);
 
   gegl_tile_handler_cache_reinit (cache);
 
@@ -750,6 +735,34 @@ gegl_tile_handler_cache_new (void)
   return g_object_new (GEGL_TYPE_TILE_HANDLER_CACHE, NULL);
 }
 
+void
+gegl_tile_handler_cache_connect (GeglTileHandlerCache *cache)
+{
+  /* join the global cache queue */
+  if (! cache->link.data)
+    {
+      cache->link.data = cache;
+
+      g_mutex_lock (&mutex);
+      g_queue_push_tail_link (&cache_queue, &cache->link);
+      g_mutex_unlock (&mutex);
+    }
+}
+
+void
+gegl_tile_handler_cache_disconnect (GeglTileHandlerCache *cache)
+{
+  /* leave the global cache queue */
+  if (cache->link.data)
+    {
+      g_mutex_lock (&mutex);
+      g_queue_unlink (&cache_queue, &cache->link);
+      g_mutex_unlock (&mutex);
+
+      cache->link.data = NULL;
+    }
+}
+
 gsize
 gegl_tile_handler_cache_get_total (void)
 {
