@@ -10,6 +10,7 @@ void gegl_op_c2g_register_type(GTypeModule *module);
 void gegl_op_checkerboard_register_type(GTypeModule *module);
 void gegl_op_dither_register_type(GTypeModule *module);
 void gegl_op_color_enhance_register_type(GTypeModule *module);
+void gegl_op_color_overlay_register_type(GTypeModule *module);
 void gegl_op_color_rotate_register_type(GTypeModule *module);
 void gegl_op_color_temperature_register_type(GTypeModule *module);
 void gegl_op_color_warp_register_type(GTypeModule *module);
@@ -75,6 +76,7 @@ void gegl_op_pixelize_register_type(GTypeModule *module);
 void gegl_op_posterize_register_type(GTypeModule *module);
 void gegl_op_radial_gradient_register_type(GTypeModule *module);
 void gegl_op_rectangle_register_type(GTypeModule *module);
+void gegl_op_recursive_transform_register_type(GTypeModule *module);
 void gegl_op_reinhard05_register_type(GTypeModule *module);
 void gegl_op_remap_register_type(GTypeModule *module);
 void gegl_op_rgb_clip_register_type(GTypeModule *module);
@@ -83,6 +85,7 @@ void gegl_op_save_register_type(GTypeModule *module);
 void gegl_op_sepia_register_type(GTypeModule *module);
 void gegl_op_slic_register_type(GTypeModule *module);
 void gegl_op_snn_mean_register_type(GTypeModule *module);
+void gegl_op_spherize_register_type(GTypeModule *module);
 void gegl_op_stress_register_type(GTypeModule *module);
 void gegl_op_stretch_contrast_hsv_register_type(GTypeModule *module);
 void gegl_op_stretch_contrast_register_type(GTypeModule *module);
@@ -130,6 +133,7 @@ gegl_module_register (GTypeModule *module)
   gegl_op_checkerboard_register_type(module);
   gegl_op_dither_register_type(module);
   gegl_op_color_enhance_register_type(module);
+  gegl_op_color_overlay_register_type(module);
   gegl_op_color_rotate_register_type(module);
   gegl_op_color_temperature_register_type(module);
   gegl_op_color_warp_register_type(module);
@@ -195,6 +199,7 @@ gegl_module_register (GTypeModule *module)
   gegl_op_posterize_register_type(module);
   gegl_op_radial_gradient_register_type(module);
   gegl_op_rectangle_register_type(module);
+  gegl_op_recursive_transform_register_type(module);
   gegl_op_reinhard05_register_type(module);
   gegl_op_remap_register_type(module);
   gegl_op_rgb_clip_register_type(module);
@@ -203,6 +208,7 @@ gegl_module_register (GTypeModule *module)
   gegl_op_sepia_register_type(module);
   gegl_op_slic_register_type(module);
   gegl_op_snn_mean_register_type(module);
+  gegl_op_spherize_register_type(module);
   gegl_op_stress_register_type(module);
   gegl_op_stretch_contrast_hsv_register_type(module);
   gegl_op_stretch_contrast_register_type(module);
