@@ -196,8 +196,8 @@ finalize (GObject *object)
           v4lclose (p->vd);
           g_free (p->vd);
         }
-      g_free (o->user_data);
-      o->user_data = NULL;
+
+      g_clear_pointer (&o->user_data, g_free);
     }
 
   G_OBJECT_CLASS (gegl_op_parent_class)->finalize (object);
